# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetRepositoryTreeResult',
    'AwaitableGetRepositoryTreeResult',
    'get_repository_tree',
    'get_repository_tree_output',
]

@pulumi.output_type
class GetRepositoryTreeResult:
    """
    A collection of values returned by getRepositoryTree.
    """
    def __init__(__self__, id=None, path=None, project=None, recursive=None, ref=None, trees=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if recursive and not isinstance(recursive, bool):
            raise TypeError("Expected argument 'recursive' to be a bool")
        pulumi.set(__self__, "recursive", recursive)
        if ref and not isinstance(ref, str):
            raise TypeError("Expected argument 'ref' to be a str")
        pulumi.set(__self__, "ref", ref)
        if trees and not isinstance(trees, list):
            raise TypeError("Expected argument 'trees' to be a list")
        pulumi.set(__self__, "trees", trees)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def path(self) -> Optional[str]:
        """
        The path inside repository. Used to get content of subdirectories.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The ID or full path of the project owned by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def recursive(self) -> Optional[bool]:
        """
        Boolean value used to get a recursive tree (false by default).
        """
        return pulumi.get(self, "recursive")

    @property
    @pulumi.getter
    def ref(self) -> str:
        """
        The name of a repository branch or tag.
        """
        return pulumi.get(self, "ref")

    @property
    @pulumi.getter
    def trees(self) -> Sequence['outputs.GetRepositoryTreeTreeResult']:
        """
        The list of files/directories returned by the search
        """
        return pulumi.get(self, "trees")


class AwaitableGetRepositoryTreeResult(GetRepositoryTreeResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryTreeResult(
            id=self.id,
            path=self.path,
            project=self.project,
            recursive=self.recursive,
            ref=self.ref,
            trees=self.trees)


def get_repository_tree(path: Optional[str] = None,
                        project: Optional[str] = None,
                        recursive: Optional[bool] = None,
                        ref: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryTreeResult:
    """
    The `get_repository_tree` data source allows details of directories and files in a repository to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/repositories.html#list-repository-tree)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    this = gitlab.get_repository_tree(project="example",
        ref="main",
        path="ExampleSubFolder",
        recursive=True)
    ```


    :param str path: The path inside repository. Used to get content of subdirectories.
    :param str project: The ID or full path of the project owned by the authenticated user.
    :param bool recursive: Boolean value used to get a recursive tree (false by default).
    :param str ref: The name of a repository branch or tag.
    """
    __args__ = dict()
    __args__['path'] = path
    __args__['project'] = project
    __args__['recursive'] = recursive
    __args__['ref'] = ref
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getRepositoryTree:getRepositoryTree', __args__, opts=opts, typ=GetRepositoryTreeResult).value

    return AwaitableGetRepositoryTreeResult(
        id=pulumi.get(__ret__, 'id'),
        path=pulumi.get(__ret__, 'path'),
        project=pulumi.get(__ret__, 'project'),
        recursive=pulumi.get(__ret__, 'recursive'),
        ref=pulumi.get(__ret__, 'ref'),
        trees=pulumi.get(__ret__, 'trees'))
def get_repository_tree_output(path: Optional[pulumi.Input[Optional[str]]] = None,
                               project: Optional[pulumi.Input[str]] = None,
                               recursive: Optional[pulumi.Input[Optional[bool]]] = None,
                               ref: Optional[pulumi.Input[str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRepositoryTreeResult]:
    """
    The `get_repository_tree` data source allows details of directories and files in a repository to be retrieved.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/repositories.html#list-repository-tree)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    this = gitlab.get_repository_tree(project="example",
        ref="main",
        path="ExampleSubFolder",
        recursive=True)
    ```


    :param str path: The path inside repository. Used to get content of subdirectories.
    :param str project: The ID or full path of the project owned by the authenticated user.
    :param bool recursive: Boolean value used to get a recursive tree (false by default).
    :param str ref: The name of a repository branch or tag.
    """
    __args__ = dict()
    __args__['path'] = path
    __args__['project'] = project
    __args__['recursive'] = recursive
    __args__['ref'] = ref
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getRepositoryTree:getRepositoryTree', __args__, opts=opts, typ=GetRepositoryTreeResult)
    return __ret__.apply(lambda __response__: GetRepositoryTreeResult(
        id=pulumi.get(__response__, 'id'),
        path=pulumi.get(__response__, 'path'),
        project=pulumi.get(__response__, 'project'),
        recursive=pulumi.get(__response__, 'recursive'),
        ref=pulumi.get(__response__, 'ref'),
        trees=pulumi.get(__response__, 'trees')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupLdapLinkArgs', 'GroupLdapLink']

@pulumi.input_type
class GroupLdapLinkArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[str],
                 ldap_provider: pulumi.Input[str],
                 access_level: Optional[pulumi.Input[str]] = None,
                 cn: Optional[pulumi.Input[str]] = None,
                 filter: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 group_access: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a GroupLdapLink resource.
        :param pulumi.Input[str] group: The ID or URL-encoded path of the group
        :param pulumi.Input[str] ldap_provider: The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        :param pulumi.Input[str] access_level: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] cn: The CN of the LDAP group to link with. Required if `filter` is not provided.
        :param pulumi.Input[str] filter: The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        :param pulumi.Input[bool] force: If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        :param pulumi.Input[str] group_access: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        pulumi.set(__self__, "group", group)
        pulumi.set(__self__, "ldap_provider", ldap_provider)
        if access_level is not None:
            warnings.warn("""Use `group_access` instead of the `access_level` attribute.""", DeprecationWarning)
            pulumi.log.warn("""access_level is deprecated: Use `group_access` instead of the `access_level` attribute.""")
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if cn is not None:
            pulumi.set(__self__, "cn", cn)
        if filter is not None:
            pulumi.set(__self__, "filter", filter)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if group_access is not None:
            pulumi.set(__self__, "group_access", group_access)

    @property
    @pulumi.getter
    def group(self) -> pulumi.Input[str]:
        """
        The ID or URL-encoded path of the group
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[str]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter(name="ldapProvider")
    def ldap_provider(self) -> pulumi.Input[str]:
        """
        The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        return pulumi.get(self, "ldap_provider")

    @ldap_provider.setter
    def ldap_provider(self, value: pulumi.Input[str]):
        pulumi.set(self, "ldap_provider", value)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> Optional[pulumi.Input[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter
    def cn(self) -> Optional[pulumi.Input[str]]:
        """
        The CN of the LDAP group to link with. Required if `filter` is not provided.
        """
        return pulumi.get(self, "cn")

    @cn.setter
    def cn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cn", value)

    @property
    @pulumi.getter
    def filter(self) -> Optional[pulumi.Input[str]]:
        """
        The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        """
        return pulumi.get(self, "filter")

    @filter.setter
    def filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> Optional[pulumi.Input[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_access", value)


@pulumi.input_type
class _GroupLdapLinkState:
    def __init__(__self__, *,
                 access_level: Optional[pulumi.Input[str]] = None,
                 cn: Optional[pulumi.Input[str]] = None,
                 filter: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 ldap_provider: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering GroupLdapLink resources.
        :param pulumi.Input[str] access_level: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] cn: The CN of the LDAP group to link with. Required if `filter` is not provided.
        :param pulumi.Input[str] filter: The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        :param pulumi.Input[bool] force: If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        :param pulumi.Input[str] group: The ID or URL-encoded path of the group
        :param pulumi.Input[str] group_access: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] ldap_provider: The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        if access_level is not None:
            warnings.warn("""Use `group_access` instead of the `access_level` attribute.""", DeprecationWarning)
            pulumi.log.warn("""access_level is deprecated: Use `group_access` instead of the `access_level` attribute.""")
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if cn is not None:
            pulumi.set(__self__, "cn", cn)
        if filter is not None:
            pulumi.set(__self__, "filter", filter)
        if force is not None:
            pulumi.set(__self__, "force", force)
        if group is not None:
            pulumi.set(__self__, "group", group)
        if group_access is not None:
            pulumi.set(__self__, "group_access", group_access)
        if ldap_provider is not None:
            pulumi.set(__self__, "ldap_provider", ldap_provider)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> Optional[pulumi.Input[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_level", value)

    @property
    @pulumi.getter
    def cn(self) -> Optional[pulumi.Input[str]]:
        """
        The CN of the LDAP group to link with. Required if `filter` is not provided.
        """
        return pulumi.get(self, "cn")

    @cn.setter
    def cn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cn", value)

    @property
    @pulumi.getter
    def filter(self) -> Optional[pulumi.Input[str]]:
        """
        The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        """
        return pulumi.get(self, "filter")

    @filter.setter
    def filter(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "filter", value)

    @property
    @pulumi.getter
    def force(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        """
        return pulumi.get(self, "force")

    @force.setter
    def force(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "force", value)

    @property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or URL-encoded path of the group
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group", value)

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> Optional[pulumi.Input[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @group_access.setter
    def group_access(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_access", value)

    @property
    @pulumi.getter(name="ldapProvider")
    def ldap_provider(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        return pulumi.get(self, "ldap_provider")

    @ldap_provider.setter
    def ldap_provider(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ldap_provider", value)


class GroupLdapLink(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[str]] = None,
                 cn: Optional[pulumi.Input[str]] = None,
                 filter: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 ldap_provider: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The `GroupLdapLink` resource allows to manage the lifecycle of an LDAP integration with a group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/groups.html#ldap-group-links)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_group_ldap_link`. For example:

        terraform

        import {

          to = gitlab_group_ldap_link.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab group ldap links can be imported using an id made up of `group_id:ldap_provider:cn:filter`. CN and Filter are mutually exclusive, so one will be missing.

        If using the CN for the group link, the ID will end with a blank filter (":"). e.g.,

        ```sh
        $ pulumi import gitlab:index/groupLdapLink:GroupLdapLink test "12345:ldapmain:testcn:"
        ```

        If using the Filter for the group link, the ID will have two "::" in the middle due to having a blank CN. e.g.,

        ```sh
        $ pulumi import gitlab:index/groupLdapLink:GroupLdapLink test "12345:ldapmain::testfilter"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] cn: The CN of the LDAP group to link with. Required if `filter` is not provided.
        :param pulumi.Input[str] filter: The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        :param pulumi.Input[bool] force: If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        :param pulumi.Input[str] group: The ID or URL-encoded path of the group
        :param pulumi.Input[str] group_access: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] ldap_provider: The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupLdapLinkArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupLdapLink` resource allows to manage the lifecycle of an LDAP integration with a group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/groups.html#ldap-group-links)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_group_ldap_link`. For example:

        terraform

        import {

          to = gitlab_group_ldap_link.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab group ldap links can be imported using an id made up of `group_id:ldap_provider:cn:filter`. CN and Filter are mutually exclusive, so one will be missing.

        If using the CN for the group link, the ID will end with a blank filter (":"). e.g.,

        ```sh
        $ pulumi import gitlab:index/groupLdapLink:GroupLdapLink test "12345:ldapmain:testcn:"
        ```

        If using the Filter for the group link, the ID will have two "::" in the middle due to having a blank CN. e.g.,

        ```sh
        $ pulumi import gitlab:index/groupLdapLink:GroupLdapLink test "12345:ldapmain::testfilter"
        ```

        :param str resource_name: The name of the resource.
        :param GroupLdapLinkArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupLdapLinkArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[str]] = None,
                 cn: Optional[pulumi.Input[str]] = None,
                 filter: Optional[pulumi.Input[str]] = None,
                 force: Optional[pulumi.Input[bool]] = None,
                 group: Optional[pulumi.Input[str]] = None,
                 group_access: Optional[pulumi.Input[str]] = None,
                 ldap_provider: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupLdapLinkArgs.__new__(GroupLdapLinkArgs)

            __props__.__dict__["access_level"] = access_level
            __props__.__dict__["cn"] = cn
            __props__.__dict__["filter"] = filter
            __props__.__dict__["force"] = force
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            __props__.__dict__["group_access"] = group_access
            if ldap_provider is None and not opts.urn:
                raise TypeError("Missing required property 'ldap_provider'")
            __props__.__dict__["ldap_provider"] = ldap_provider
        super(GroupLdapLink, __self__).__init__(
            'gitlab:index/groupLdapLink:GroupLdapLink',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_level: Optional[pulumi.Input[str]] = None,
            cn: Optional[pulumi.Input[str]] = None,
            filter: Optional[pulumi.Input[str]] = None,
            force: Optional[pulumi.Input[bool]] = None,
            group: Optional[pulumi.Input[str]] = None,
            group_access: Optional[pulumi.Input[str]] = None,
            ldap_provider: Optional[pulumi.Input[str]] = None) -> 'GroupLdapLink':
        """
        Get an existing GroupLdapLink resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] cn: The CN of the LDAP group to link with. Required if `filter` is not provided.
        :param pulumi.Input[str] filter: The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        :param pulumi.Input[bool] force: If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        :param pulumi.Input[str] group: The ID or URL-encoded path of the group
        :param pulumi.Input[str] group_access: Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        :param pulumi.Input[str] ldap_provider: The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupLdapLinkState.__new__(_GroupLdapLinkState)

        __props__.__dict__["access_level"] = access_level
        __props__.__dict__["cn"] = cn
        __props__.__dict__["filter"] = filter
        __props__.__dict__["force"] = force
        __props__.__dict__["group"] = group
        __props__.__dict__["group_access"] = group_access
        __props__.__dict__["ldap_provider"] = ldap_provider
        return GroupLdapLink(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessLevel")
    @_utilities.deprecated("""Use `group_access` instead of the `access_level` attribute.""")
    def access_level(self) -> pulumi.Output[Optional[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "access_level")

    @property
    @pulumi.getter
    def cn(self) -> pulumi.Output[str]:
        """
        The CN of the LDAP group to link with. Required if `filter` is not provided.
        """
        return pulumi.get(self, "cn")

    @property
    @pulumi.getter
    def filter(self) -> pulumi.Output[str]:
        """
        The LDAP filter for the group. Required if `cn` is not provided. Requires GitLab Premium or above.
        """
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def force(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, then delete and replace an existing LDAP link if one exists. Will also remove an LDAP link if the parent group is not found.
        """
        return pulumi.get(self, "force")

    @property
    @pulumi.getter
    def group(self) -> pulumi.Output[str]:
        """
        The ID or URL-encoded path of the group
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter(name="groupAccess")
    def group_access(self) -> pulumi.Output[Optional[str]]:
        """
        Minimum access level for members of the LDAP group. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`
        """
        return pulumi.get(self, "group_access")

    @property
    @pulumi.getter(name="ldapProvider")
    def ldap_provider(self) -> pulumi.Output[str]:
        """
        The name of the LDAP provider as stored in the GitLab database. Note that this is NOT the value of the `label` attribute as shown in the web UI. In most cases this will be `ldapmain` but you may use the [LDAP check rake task](https://docs.gitlab.com/ee/administration/raketasks/ldap.html#check) for receiving the LDAP server name: `LDAP: ... Server: ldapmain`
        """
        return pulumi.get(self, "ldap_provider")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectIssuesResult',
    'AwaitableGetProjectIssuesResult',
    'get_project_issues',
    'get_project_issues_output',
]

@pulumi.output_type
class GetProjectIssuesResult:
    """
    A collection of values returned by getProjectIssues.
    """
    def __init__(__self__, assignee_id=None, assignee_username=None, author_id=None, confidential=None, created_after=None, created_before=None, due_date=None, id=None, iids=None, issue_type=None, issues=None, labels=None, milestone=None, my_reaction_emoji=None, not_assignee_ids=None, not_author_ids=None, not_labels=None, not_milestone=None, not_my_reaction_emojis=None, order_by=None, project=None, scope=None, search=None, sort=None, updated_after=None, updated_before=None, weight=None, with_labels_details=None):
        if assignee_id and not isinstance(assignee_id, int):
            raise TypeError("Expected argument 'assignee_id' to be a int")
        pulumi.set(__self__, "assignee_id", assignee_id)
        if assignee_username and not isinstance(assignee_username, str):
            raise TypeError("Expected argument 'assignee_username' to be a str")
        pulumi.set(__self__, "assignee_username", assignee_username)
        if author_id and not isinstance(author_id, int):
            raise TypeError("Expected argument 'author_id' to be a int")
        pulumi.set(__self__, "author_id", author_id)
        if confidential and not isinstance(confidential, bool):
            raise TypeError("Expected argument 'confidential' to be a bool")
        pulumi.set(__self__, "confidential", confidential)
        if created_after and not isinstance(created_after, str):
            raise TypeError("Expected argument 'created_after' to be a str")
        pulumi.set(__self__, "created_after", created_after)
        if created_before and not isinstance(created_before, str):
            raise TypeError("Expected argument 'created_before' to be a str")
        pulumi.set(__self__, "created_before", created_before)
        if due_date and not isinstance(due_date, str):
            raise TypeError("Expected argument 'due_date' to be a str")
        pulumi.set(__self__, "due_date", due_date)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iids and not isinstance(iids, list):
            raise TypeError("Expected argument 'iids' to be a list")
        pulumi.set(__self__, "iids", iids)
        if issue_type and not isinstance(issue_type, str):
            raise TypeError("Expected argument 'issue_type' to be a str")
        pulumi.set(__self__, "issue_type", issue_type)
        if issues and not isinstance(issues, list):
            raise TypeError("Expected argument 'issues' to be a list")
        pulumi.set(__self__, "issues", issues)
        if labels and not isinstance(labels, list):
            raise TypeError("Expected argument 'labels' to be a list")
        pulumi.set(__self__, "labels", labels)
        if milestone and not isinstance(milestone, str):
            raise TypeError("Expected argument 'milestone' to be a str")
        pulumi.set(__self__, "milestone", milestone)
        if my_reaction_emoji and not isinstance(my_reaction_emoji, str):
            raise TypeError("Expected argument 'my_reaction_emoji' to be a str")
        pulumi.set(__self__, "my_reaction_emoji", my_reaction_emoji)
        if not_assignee_ids and not isinstance(not_assignee_ids, list):
            raise TypeError("Expected argument 'not_assignee_ids' to be a list")
        pulumi.set(__self__, "not_assignee_ids", not_assignee_ids)
        if not_author_ids and not isinstance(not_author_ids, list):
            raise TypeError("Expected argument 'not_author_ids' to be a list")
        pulumi.set(__self__, "not_author_ids", not_author_ids)
        if not_labels and not isinstance(not_labels, list):
            raise TypeError("Expected argument 'not_labels' to be a list")
        pulumi.set(__self__, "not_labels", not_labels)
        if not_milestone and not isinstance(not_milestone, str):
            raise TypeError("Expected argument 'not_milestone' to be a str")
        pulumi.set(__self__, "not_milestone", not_milestone)
        if not_my_reaction_emojis and not isinstance(not_my_reaction_emojis, list):
            raise TypeError("Expected argument 'not_my_reaction_emojis' to be a list")
        pulumi.set(__self__, "not_my_reaction_emojis", not_my_reaction_emojis)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        pulumi.set(__self__, "sort", sort)
        if updated_after and not isinstance(updated_after, str):
            raise TypeError("Expected argument 'updated_after' to be a str")
        pulumi.set(__self__, "updated_after", updated_after)
        if updated_before and not isinstance(updated_before, str):
            raise TypeError("Expected argument 'updated_before' to be a str")
        pulumi.set(__self__, "updated_before", updated_before)
        if weight and not isinstance(weight, int):
            raise TypeError("Expected argument 'weight' to be a int")
        pulumi.set(__self__, "weight", weight)
        if with_labels_details and not isinstance(with_labels_details, bool):
            raise TypeError("Expected argument 'with_labels_details' to be a bool")
        pulumi.set(__self__, "with_labels_details", with_labels_details)

    @property
    @pulumi.getter(name="assigneeId")
    def assignee_id(self) -> Optional[int]:
        """
        Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
        """
        return pulumi.get(self, "assignee_id")

    @property
    @pulumi.getter(name="assigneeUsername")
    def assignee_username(self) -> Optional[str]:
        """
        Return issues assigned to the given username. Similar to assignee*id and mutually exclusive with assignee*id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
        """
        return pulumi.get(self, "assignee_username")

    @property
    @pulumi.getter(name="authorId")
    def author_id(self) -> Optional[int]:
        """
        Return issues created by the given user id. Combine with scope=all or scope=assigned*to*me.
        """
        return pulumi.get(self, "author_id")

    @property
    @pulumi.getter
    def confidential(self) -> Optional[bool]:
        """
        Filter confidential or public issues.
        """
        return pulumi.get(self, "confidential")

    @property
    @pulumi.getter(name="createdAfter")
    def created_after(self) -> Optional[str]:
        """
        Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
        """
        return pulumi.get(self, "created_after")

    @property
    @pulumi.getter(name="createdBefore")
    def created_before(self) -> Optional[str]:
        """
        Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
        """
        return pulumi.get(self, "created_before")

    @property
    @pulumi.getter(name="dueDate")
    def due_date(self) -> Optional[str]:
        """
        Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next*month*and*previous*two_weeks.
        """
        return pulumi.get(self, "due_date")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def iids(self) -> Optional[Sequence[int]]:
        """
        Return only the issues having the given iid
        """
        return pulumi.get(self, "iids")

    @property
    @pulumi.getter(name="issueType")
    def issue_type(self) -> Optional[str]:
        """
        Filter to a given type of issue. Valid values are [issue incident test_case]. (Introduced in GitLab 13.12)
        """
        return pulumi.get(self, "issue_type")

    @property
    @pulumi.getter
    def issues(self) -> Sequence['outputs.GetProjectIssuesIssueResult']:
        """
        The list of issues returned by the search.
        """
        return pulumi.get(self, "issues")

    @property
    @pulumi.getter
    def labels(self) -> Optional[Sequence[str]]:
        """
        Return issues with labels. Issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def milestone(self) -> Optional[str]:
        """
        The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone.
        """
        return pulumi.get(self, "milestone")

    @property
    @pulumi.getter(name="myReactionEmoji")
    def my_reaction_emoji(self) -> Optional[str]:
        """
        Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
        """
        return pulumi.get(self, "my_reaction_emoji")

    @property
    @pulumi.getter(name="notAssigneeIds")
    def not_assignee_ids(self) -> Optional[Sequence[int]]:
        """
        Return issues that do not match the assignee id.
        """
        return pulumi.get(self, "not_assignee_ids")

    @property
    @pulumi.getter(name="notAuthorIds")
    def not_author_ids(self) -> Optional[Sequence[int]]:
        """
        Return issues that do not match the author id.
        """
        return pulumi.get(self, "not_author_ids")

    @property
    @pulumi.getter(name="notLabels")
    def not_labels(self) -> Optional[Sequence[str]]:
        """
        Return issues that do not match the labels.
        """
        return pulumi.get(self, "not_labels")

    @property
    @pulumi.getter(name="notMilestone")
    def not_milestone(self) -> Optional[str]:
        """
        Return issues that do not match the milestone.
        """
        return pulumi.get(self, "not_milestone")

    @property
    @pulumi.getter(name="notMyReactionEmojis")
    def not_my_reaction_emojis(self) -> Optional[Sequence[str]]:
        """
        Return issues not reacted by the authenticated user by the given emoji.
        """
        return pulumi.get(self, "not_my_reaction_emojis")

    @property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[str]:
        """
        Return issues ordered by. Valid values are `created_at`, `updated_at`, `priority`, `due_date`, `relative_position`, `label_priority`, `milestone_due`, `popularity`, `weight`. Default is created_at
        """
        return pulumi.get(self, "order_by")

    @property
    @pulumi.getter
    def project(self) -> str:
        """
        The name or id of the project.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def scope(self) -> Optional[str]:
        """
        Return issues for the given scope. Valid values are `created_by_me`, `assigned_to_me`, `all`. Defaults to all.
        """
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter
    def search(self) -> Optional[str]:
        """
        Search project issues against their title and description
        """
        return pulumi.get(self, "search")

    @property
    @pulumi.getter
    def sort(self) -> Optional[str]:
        """
        Return issues sorted in asc or desc order. Default is desc
        """
        return pulumi.get(self, "sort")

    @property
    @pulumi.getter(name="updatedAfter")
    def updated_after(self) -> Optional[str]:
        """
        Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
        """
        return pulumi.get(self, "updated_after")

    @property
    @pulumi.getter(name="updatedBefore")
    def updated_before(self) -> Optional[str]:
        """
        Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
        """
        return pulumi.get(self, "updated_before")

    @property
    @pulumi.getter
    def weight(self) -> Optional[int]:
        """
        Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
        """
        return pulumi.get(self, "weight")

    @property
    @pulumi.getter(name="withLabelsDetails")
    def with_labels_details(self) -> Optional[bool]:
        """
        If true, the response returns more details for each label in labels field: :name, :color, :description, :description*html, :text*color. Default is false. description_html was introduced in GitLab 12.7
        """
        return pulumi.get(self, "with_labels_details")


class AwaitableGetProjectIssuesResult(GetProjectIssuesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectIssuesResult(
            assignee_id=self.assignee_id,
            assignee_username=self.assignee_username,
            author_id=self.author_id,
            confidential=self.confidential,
            created_after=self.created_after,
            created_before=self.created_before,
            due_date=self.due_date,
            id=self.id,
            iids=self.iids,
            issue_type=self.issue_type,
            issues=self.issues,
            labels=self.labels,
            milestone=self.milestone,
            my_reaction_emoji=self.my_reaction_emoji,
            not_assignee_ids=self.not_assignee_ids,
            not_author_ids=self.not_author_ids,
            not_labels=self.not_labels,
            not_milestone=self.not_milestone,
            not_my_reaction_emojis=self.not_my_reaction_emojis,
            order_by=self.order_by,
            project=self.project,
            scope=self.scope,
            search=self.search,
            sort=self.sort,
            updated_after=self.updated_after,
            updated_before=self.updated_before,
            weight=self.weight,
            with_labels_details=self.with_labels_details)


def get_project_issues(assignee_id: Optional[int] = None,
                       assignee_username: Optional[str] = None,
                       author_id: Optional[int] = None,
                       confidential: Optional[bool] = None,
                       created_after: Optional[str] = None,
                       created_before: Optional[str] = None,
                       due_date: Optional[str] = None,
                       iids: Optional[Sequence[int]] = None,
                       issue_type: Optional[str] = None,
                       labels: Optional[Sequence[str]] = None,
                       milestone: Optional[str] = None,
                       my_reaction_emoji: Optional[str] = None,
                       not_assignee_ids: Optional[Sequence[int]] = None,
                       not_author_ids: Optional[Sequence[int]] = None,
                       not_labels: Optional[Sequence[str]] = None,
                       not_milestone: Optional[str] = None,
                       not_my_reaction_emojis: Optional[Sequence[str]] = None,
                       order_by: Optional[str] = None,
                       project: Optional[str] = None,
                       scope: Optional[str] = None,
                       search: Optional[str] = None,
                       sort: Optional[str] = None,
                       updated_after: Optional[str] = None,
                       updated_before: Optional[str] = None,
                       weight: Optional[int] = None,
                       with_labels_details: Optional[bool] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectIssuesResult:
    """
    The `get_project_issues` data source allows to retrieve details about issues in a project.

    **Upstream API**: [GitLab API docs](https://docs.gitlab.com/ee/api/issues.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_project(id="foo/bar/baz")
    all_with_foo = gitlab.get_project_issues(project=foo.id,
        search="foo")
    ```


    :param int assignee_id: Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
    :param str assignee_username: Return issues assigned to the given username. Similar to assignee*id and mutually exclusive with assignee*id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
    :param int author_id: Return issues created by the given user id. Combine with scope=all or scope=assigned*to*me.
    :param bool confidential: Filter confidential or public issues.
    :param str created_after: Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str created_before: Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str due_date: Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next*month*and*previous*two_weeks.
    :param Sequence[int] iids: Return only the issues having the given iid
    :param str issue_type: Filter to a given type of issue. Valid values are [issue incident test_case]. (Introduced in GitLab 13.12)
    :param Sequence[str] labels: Return issues with labels. Issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
    :param str milestone: The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone.
    :param str my_reaction_emoji: Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
    :param Sequence[int] not_assignee_ids: Return issues that do not match the assignee id.
    :param Sequence[int] not_author_ids: Return issues that do not match the author id.
    :param Sequence[str] not_labels: Return issues that do not match the labels.
    :param str not_milestone: Return issues that do not match the milestone.
    :param Sequence[str] not_my_reaction_emojis: Return issues not reacted by the authenticated user by the given emoji.
    :param str order_by: Return issues ordered by. Valid values are `created_at`, `updated_at`, `priority`, `due_date`, `relative_position`, `label_priority`, `milestone_due`, `popularity`, `weight`. Default is created_at
    :param str project: The name or id of the project.
    :param str scope: Return issues for the given scope. Valid values are `created_by_me`, `assigned_to_me`, `all`. Defaults to all.
    :param str search: Search project issues against their title and description
    :param str sort: Return issues sorted in asc or desc order. Default is desc
    :param str updated_after: Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str updated_before: Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param int weight: Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
    :param bool with_labels_details: If true, the response returns more details for each label in labels field: :name, :color, :description, :description*html, :text*color. Default is false. description_html was introduced in GitLab 12.7
    """
    __args__ = dict()
    __args__['assigneeId'] = assignee_id
    __args__['assigneeUsername'] = assignee_username
    __args__['authorId'] = author_id
    __args__['confidential'] = confidential
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['dueDate'] = due_date
    __args__['iids'] = iids
    __args__['issueType'] = issue_type
    __args__['labels'] = labels
    __args__['milestone'] = milestone
    __args__['myReactionEmoji'] = my_reaction_emoji
    __args__['notAssigneeIds'] = not_assignee_ids
    __args__['notAuthorIds'] = not_author_ids
    __args__['notLabels'] = not_labels
    __args__['notMilestone'] = not_milestone
    __args__['notMyReactionEmojis'] = not_my_reaction_emojis
    __args__['orderBy'] = order_by
    __args__['project'] = project
    __args__['scope'] = scope
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['updatedAfter'] = updated_after
    __args__['updatedBefore'] = updated_before
    __args__['weight'] = weight
    __args__['withLabelsDetails'] = with_labels_details
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectIssues:getProjectIssues', __args__, opts=opts, typ=GetProjectIssuesResult).value

    return AwaitableGetProjectIssuesResult(
        assignee_id=pulumi.get(__ret__, 'assignee_id'),
        assignee_username=pulumi.get(__ret__, 'assignee_username'),
        author_id=pulumi.get(__ret__, 'author_id'),
        confidential=pulumi.get(__ret__, 'confidential'),
        created_after=pulumi.get(__ret__, 'created_after'),
        created_before=pulumi.get(__ret__, 'created_before'),
        due_date=pulumi.get(__ret__, 'due_date'),
        id=pulumi.get(__ret__, 'id'),
        iids=pulumi.get(__ret__, 'iids'),
        issue_type=pulumi.get(__ret__, 'issue_type'),
        issues=pulumi.get(__ret__, 'issues'),
        labels=pulumi.get(__ret__, 'labels'),
        milestone=pulumi.get(__ret__, 'milestone'),
        my_reaction_emoji=pulumi.get(__ret__, 'my_reaction_emoji'),
        not_assignee_ids=pulumi.get(__ret__, 'not_assignee_ids'),
        not_author_ids=pulumi.get(__ret__, 'not_author_ids'),
        not_labels=pulumi.get(__ret__, 'not_labels'),
        not_milestone=pulumi.get(__ret__, 'not_milestone'),
        not_my_reaction_emojis=pulumi.get(__ret__, 'not_my_reaction_emojis'),
        order_by=pulumi.get(__ret__, 'order_by'),
        project=pulumi.get(__ret__, 'project'),
        scope=pulumi.get(__ret__, 'scope'),
        search=pulumi.get(__ret__, 'search'),
        sort=pulumi.get(__ret__, 'sort'),
        updated_after=pulumi.get(__ret__, 'updated_after'),
        updated_before=pulumi.get(__ret__, 'updated_before'),
        weight=pulumi.get(__ret__, 'weight'),
        with_labels_details=pulumi.get(__ret__, 'with_labels_details'))
def get_project_issues_output(assignee_id: Optional[pulumi.Input[Optional[int]]] = None,
                              assignee_username: Optional[pulumi.Input[Optional[str]]] = None,
                              author_id: Optional[pulumi.Input[Optional[int]]] = None,
                              confidential: Optional[pulumi.Input[Optional[bool]]] = None,
                              created_after: Optional[pulumi.Input[Optional[str]]] = None,
                              created_before: Optional[pulumi.Input[Optional[str]]] = None,
                              due_date: Optional[pulumi.Input[Optional[str]]] = None,
                              iids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                              issue_type: Optional[pulumi.Input[Optional[str]]] = None,
                              labels: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              milestone: Optional[pulumi.Input[Optional[str]]] = None,
                              my_reaction_emoji: Optional[pulumi.Input[Optional[str]]] = None,
                              not_assignee_ids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                              not_author_ids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                              not_labels: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              not_milestone: Optional[pulumi.Input[Optional[str]]] = None,
                              not_my_reaction_emojis: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                              order_by: Optional[pulumi.Input[Optional[str]]] = None,
                              project: Optional[pulumi.Input[str]] = None,
                              scope: Optional[pulumi.Input[Optional[str]]] = None,
                              search: Optional[pulumi.Input[Optional[str]]] = None,
                              sort: Optional[pulumi.Input[Optional[str]]] = None,
                              updated_after: Optional[pulumi.Input[Optional[str]]] = None,
                              updated_before: Optional[pulumi.Input[Optional[str]]] = None,
                              weight: Optional[pulumi.Input[Optional[int]]] = None,
                              with_labels_details: Optional[pulumi.Input[Optional[bool]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectIssuesResult]:
    """
    The `get_project_issues` data source allows to retrieve details about issues in a project.

    **Upstream API**: [GitLab API docs](https://docs.gitlab.com/ee/api/issues.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_project(id="foo/bar/baz")
    all_with_foo = gitlab.get_project_issues(project=foo.id,
        search="foo")
    ```


    :param int assignee_id: Return issues assigned to the given user id. Mutually exclusive with assignee_username. None returns unassigned issues. Any returns issues with an assignee.
    :param str assignee_username: Return issues assigned to the given username. Similar to assignee*id and mutually exclusive with assignee*id. In GitLab CE, the assignee_username array should only contain a single value. Otherwise, an invalid parameter error is returned.
    :param int author_id: Return issues created by the given user id. Combine with scope=all or scope=assigned*to*me.
    :param bool confidential: Filter confidential or public issues.
    :param str created_after: Return issues created on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str created_before: Return issues created on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str due_date: Return issues that have no due date, are overdue, or whose due date is this week, this month, or between two weeks ago and next month. Accepts: 0 (no due date), any, today, tomorrow, overdue, week, month, next*month*and*previous*two_weeks.
    :param Sequence[int] iids: Return only the issues having the given iid
    :param str issue_type: Filter to a given type of issue. Valid values are [issue incident test_case]. (Introduced in GitLab 13.12)
    :param Sequence[str] labels: Return issues with labels. Issues must have all labels to be returned. None lists all issues with no labels. Any lists all issues with at least one label. No+Label (Deprecated) lists all issues with no labels. Predefined names are case-insensitive.
    :param str milestone: The milestone title. None lists all issues with no milestone. Any lists all issues that have an assigned milestone.
    :param str my_reaction_emoji: Return issues reacted by the authenticated user by the given emoji. None returns issues not given a reaction. Any returns issues given at least one reaction.
    :param Sequence[int] not_assignee_ids: Return issues that do not match the assignee id.
    :param Sequence[int] not_author_ids: Return issues that do not match the author id.
    :param Sequence[str] not_labels: Return issues that do not match the labels.
    :param str not_milestone: Return issues that do not match the milestone.
    :param Sequence[str] not_my_reaction_emojis: Return issues not reacted by the authenticated user by the given emoji.
    :param str order_by: Return issues ordered by. Valid values are `created_at`, `updated_at`, `priority`, `due_date`, `relative_position`, `label_priority`, `milestone_due`, `popularity`, `weight`. Default is created_at
    :param str project: The name or id of the project.
    :param str scope: Return issues for the given scope. Valid values are `created_by_me`, `assigned_to_me`, `all`. Defaults to all.
    :param str search: Search project issues against their title and description
    :param str sort: Return issues sorted in asc or desc order. Default is desc
    :param str updated_after: Return issues updated on or after the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param str updated_before: Return issues updated on or before the given time. Expected in ISO 8601 format (2019-03-15T08:00:00Z)
    :param int weight: Return issues with the specified weight. None returns issues with no weight assigned. Any returns issues with a weight assigned.
    :param bool with_labels_details: If true, the response returns more details for each label in labels field: :name, :color, :description, :description*html, :text*color. Default is false. description_html was introduced in GitLab 12.7
    """
    __args__ = dict()
    __args__['assigneeId'] = assignee_id
    __args__['assigneeUsername'] = assignee_username
    __args__['authorId'] = author_id
    __args__['confidential'] = confidential
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['dueDate'] = due_date
    __args__['iids'] = iids
    __args__['issueType'] = issue_type
    __args__['labels'] = labels
    __args__['milestone'] = milestone
    __args__['myReactionEmoji'] = my_reaction_emoji
    __args__['notAssigneeIds'] = not_assignee_ids
    __args__['notAuthorIds'] = not_author_ids
    __args__['notLabels'] = not_labels
    __args__['notMilestone'] = not_milestone
    __args__['notMyReactionEmojis'] = not_my_reaction_emojis
    __args__['orderBy'] = order_by
    __args__['project'] = project
    __args__['scope'] = scope
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['updatedAfter'] = updated_after
    __args__['updatedBefore'] = updated_before
    __args__['weight'] = weight
    __args__['withLabelsDetails'] = with_labels_details
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectIssues:getProjectIssues', __args__, opts=opts, typ=GetProjectIssuesResult)
    return __ret__.apply(lambda __response__: GetProjectIssuesResult(
        assignee_id=pulumi.get(__response__, 'assignee_id'),
        assignee_username=pulumi.get(__response__, 'assignee_username'),
        author_id=pulumi.get(__response__, 'author_id'),
        confidential=pulumi.get(__response__, 'confidential'),
        created_after=pulumi.get(__response__, 'created_after'),
        created_before=pulumi.get(__response__, 'created_before'),
        due_date=pulumi.get(__response__, 'due_date'),
        id=pulumi.get(__response__, 'id'),
        iids=pulumi.get(__response__, 'iids'),
        issue_type=pulumi.get(__response__, 'issue_type'),
        issues=pulumi.get(__response__, 'issues'),
        labels=pulumi.get(__response__, 'labels'),
        milestone=pulumi.get(__response__, 'milestone'),
        my_reaction_emoji=pulumi.get(__response__, 'my_reaction_emoji'),
        not_assignee_ids=pulumi.get(__response__, 'not_assignee_ids'),
        not_author_ids=pulumi.get(__response__, 'not_author_ids'),
        not_labels=pulumi.get(__response__, 'not_labels'),
        not_milestone=pulumi.get(__response__, 'not_milestone'),
        not_my_reaction_emojis=pulumi.get(__response__, 'not_my_reaction_emojis'),
        order_by=pulumi.get(__response__, 'order_by'),
        project=pulumi.get(__response__, 'project'),
        scope=pulumi.get(__response__, 'scope'),
        search=pulumi.get(__response__, 'search'),
        sort=pulumi.get(__response__, 'sort'),
        updated_after=pulumi.get(__response__, 'updated_after'),
        updated_before=pulumi.get(__response__, 'updated_before'),
        weight=pulumi.get(__response__, 'weight'),
        with_labels_details=pulumi.get(__response__, 'with_labels_details')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetInstanceVariablesResult',
    'AwaitableGetInstanceVariablesResult',
    'get_instance_variables',
    'get_instance_variables_output',
]

@pulumi.output_type
class GetInstanceVariablesResult:
    """
    A collection of values returned by getInstanceVariables.
    """
    def __init__(__self__, id=None, variables=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if variables and not isinstance(variables, list):
            raise TypeError("Expected argument 'variables' to be a list")
        pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def variables(self) -> Sequence['outputs.GetInstanceVariablesVariableResult']:
        """
        The list of variables returned by the search
        """
        return pulumi.get(self, "variables")


class AwaitableGetInstanceVariablesResult(GetInstanceVariablesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceVariablesResult(
            id=self.id,
            variables=self.variables)


def get_instance_variables(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceVariablesResult:
    """
    The `get_instance_variables` data source allows to retrieve all instance-level CI/CD variables.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/instance_level_ci_variables.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    vars = gitlab.get_instance_variables()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getInstanceVariables:getInstanceVariables', __args__, opts=opts, typ=GetInstanceVariablesResult).value

    return AwaitableGetInstanceVariablesResult(
        id=pulumi.get(__ret__, 'id'),
        variables=pulumi.get(__ret__, 'variables'))
def get_instance_variables_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstanceVariablesResult]:
    """
    The `get_instance_variables` data source allows to retrieve all instance-level CI/CD variables.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/instance_level_ci_variables.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    vars = gitlab.get_instance_variables()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getInstanceVariables:getInstanceVariables', __args__, opts=opts, typ=GetInstanceVariablesResult)
    return __ret__.apply(lambda __response__: GetInstanceVariablesResult(
        id=pulumi.get(__response__, 'id'),
        variables=pulumi.get(__response__, 'variables')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGroupVariablesResult',
    'AwaitableGetGroupVariablesResult',
    'get_group_variables',
    'get_group_variables_output',
]

@pulumi.output_type
class GetGroupVariablesResult:
    """
    A collection of values returned by getGroupVariables.
    """
    def __init__(__self__, environment_scope=None, group=None, id=None, variables=None):
        if environment_scope and not isinstance(environment_scope, str):
            raise TypeError("Expected argument 'environment_scope' to be a str")
        pulumi.set(__self__, "environment_scope", environment_scope)
        if group and not isinstance(group, str):
            raise TypeError("Expected argument 'group' to be a str")
        pulumi.set(__self__, "group", group)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if variables and not isinstance(variables, list):
            raise TypeError("Expected argument 'variables' to be a list")
        pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="environmentScope")
    def environment_scope(self) -> Optional[str]:
        """
        The environment scope of the variable. Defaults to all environment (`*`).
        """
        return pulumi.get(self, "environment_scope")

    @property
    @pulumi.getter
    def group(self) -> str:
        """
        The name or id of the group.
        """
        return pulumi.get(self, "group")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def variables(self) -> Sequence['outputs.GetGroupVariablesVariableResult']:
        """
        The list of variables returned by the search
        """
        return pulumi.get(self, "variables")


class AwaitableGetGroupVariablesResult(GetGroupVariablesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupVariablesResult(
            environment_scope=self.environment_scope,
            group=self.group,
            id=self.id,
            variables=self.variables)


def get_group_variables(environment_scope: Optional[str] = None,
                        group: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGroupVariablesResult:
    """
    The `get_group_variables` data source allows to retrieve all group-level CI/CD variables.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/group_level_variables.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    vars = gitlab.get_group_variables(group="my/example/group")
    # Using an environment scope
    staging_vars = gitlab.get_group_variables(group="my/example/group",
        environment_scope="staging/*")
    ```


    :param str environment_scope: The environment scope of the variable. Defaults to all environment (`*`).
    :param str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['environmentScope'] = environment_scope
    __args__['group'] = group
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroupVariables:getGroupVariables', __args__, opts=opts, typ=GetGroupVariablesResult).value

    return AwaitableGetGroupVariablesResult(
        environment_scope=pulumi.get(__ret__, 'environment_scope'),
        group=pulumi.get(__ret__, 'group'),
        id=pulumi.get(__ret__, 'id'),
        variables=pulumi.get(__ret__, 'variables'))
def get_group_variables_output(environment_scope: Optional[pulumi.Input[Optional[str]]] = None,
                               group: Optional[pulumi.Input[str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGroupVariablesResult]:
    """
    The `get_group_variables` data source allows to retrieve all group-level CI/CD variables.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/group_level_variables.html)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    vars = gitlab.get_group_variables(group="my/example/group")
    # Using an environment scope
    staging_vars = gitlab.get_group_variables(group="my/example/group",
        environment_scope="staging/*")
    ```


    :param str environment_scope: The environment scope of the variable. Defaults to all environment (`*`).
    :param str group: The name or id of the group.
    """
    __args__ = dict()
    __args__['environmentScope'] = environment_scope
    __args__['group'] = group
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getGroupVariables:getGroupVariables', __args__, opts=opts, typ=GetGroupVariablesResult)
    return __ret__.apply(lambda __response__: GetGroupVariablesResult(
        environment_scope=pulumi.get(__response__, 'environment_scope'),
        group=pulumi.get(__response__, 'group'),
        id=pulumi.get(__response__, 'id'),
        variables=pulumi.get(__response__, 'variables')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectIssueBoardArgs', 'ProjectIssueBoard']

@pulumi.input_type
class ProjectIssueBoardArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[str],
                 assignee_id: Optional[pulumi.Input[int]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a ProjectIssueBoard resource.
        :param pulumi.Input[str] project: The ID or full path of the project maintained by the authenticated user.
        :param pulumi.Input[int] assignee_id: The assignee the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The list of label names which the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]] lists: The list of issue board lists
        :param pulumi.Input[int] milestone_id: The milestone the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[str] name: The name of the board.
        :param pulumi.Input[int] weight: The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        pulumi.set(__self__, "project", project)
        if assignee_id is not None:
            pulumi.set(__self__, "assignee_id", assignee_id)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if lists is not None:
            pulumi.set(__self__, "lists", lists)
        if milestone_id is not None:
            pulumi.set(__self__, "milestone_id", milestone_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or full path of the project maintained by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="assigneeId")
    def assignee_id(self) -> Optional[pulumi.Input[int]]:
        """
        The assignee the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "assignee_id")

    @assignee_id.setter
    def assignee_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "assignee_id", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of label names which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]]:
        """
        The list of issue board lists
        """
        return pulumi.get(self, "lists")

    @lists.setter
    def lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]]):
        pulumi.set(self, "lists", value)

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> Optional[pulumi.Input[int]]:
        """
        The milestone the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "milestone_id")

    @milestone_id.setter
    def milestone_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "milestone_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the board.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _ProjectIssueBoardState:
    def __init__(__self__, *,
                 assignee_id: Optional[pulumi.Input[int]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering ProjectIssueBoard resources.
        :param pulumi.Input[int] assignee_id: The assignee the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The list of label names which the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]] lists: The list of issue board lists
        :param pulumi.Input[int] milestone_id: The milestone the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[str] name: The name of the board.
        :param pulumi.Input[str] project: The ID or full path of the project maintained by the authenticated user.
        :param pulumi.Input[int] weight: The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        if assignee_id is not None:
            pulumi.set(__self__, "assignee_id", assignee_id)
        if labels is not None:
            pulumi.set(__self__, "labels", labels)
        if lists is not None:
            pulumi.set(__self__, "lists", lists)
        if milestone_id is not None:
            pulumi.set(__self__, "milestone_id", milestone_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="assigneeId")
    def assignee_id(self) -> Optional[pulumi.Input[int]]:
        """
        The assignee the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "assignee_id")

    @assignee_id.setter
    def assignee_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "assignee_id", value)

    @property
    @pulumi.getter
    def labels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        The list of label names which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "labels")

    @labels.setter
    def labels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "labels", value)

    @property
    @pulumi.getter
    def lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]]:
        """
        The list of issue board lists
        """
        return pulumi.get(self, "lists")

    @lists.setter
    def lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectIssueBoardListArgs']]]]):
        pulumi.set(self, "lists", value)

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> Optional[pulumi.Input[int]]:
        """
        The milestone the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "milestone_id")

    @milestone_id.setter
    def milestone_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "milestone_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the board.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or full path of the project maintained by the authenticated user.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


class ProjectIssueBoard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignee_id: Optional[pulumi.Input[int]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectIssueBoardListArgs', 'ProjectIssueBoardListArgsDict']]]]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        The `ProjectIssueBoard` resource allows to manage the lifecycle of a Project Issue Board.

        > **NOTE:** If the board lists are changed all lists will be recreated.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/boards.html)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_issue_board`. For example:

        terraform

        import {

          to = gitlab_project_issue_board.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import this resource with an id made up of `{project-id}:{issue-board-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssueBoard:ProjectIssueBoard kanban 42:1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] assignee_id: The assignee the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The list of label names which the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectIssueBoardListArgs', 'ProjectIssueBoardListArgsDict']]]] lists: The list of issue board lists
        :param pulumi.Input[int] milestone_id: The milestone the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[str] name: The name of the board.
        :param pulumi.Input[str] project: The ID or full path of the project maintained by the authenticated user.
        :param pulumi.Input[int] weight: The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectIssueBoardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectIssueBoard` resource allows to manage the lifecycle of a Project Issue Board.

        > **NOTE:** If the board lists are changed all lists will be recreated.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/ee/api/boards.html)

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_issue_board`. For example:

        terraform

        import {

          to = gitlab_project_issue_board.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        You can import this resource with an id made up of `{project-id}:{issue-board-id}`, e.g.

        ```sh
        $ pulumi import gitlab:index/projectIssueBoard:ProjectIssueBoard kanban 42:1
        ```

        :param str resource_name: The name of the resource.
        :param ProjectIssueBoardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectIssueBoardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assignee_id: Optional[pulumi.Input[int]] = None,
                 labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectIssueBoardListArgs', 'ProjectIssueBoardListArgsDict']]]]] = None,
                 milestone_id: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectIssueBoardArgs.__new__(ProjectIssueBoardArgs)

            __props__.__dict__["assignee_id"] = assignee_id
            __props__.__dict__["labels"] = labels
            __props__.__dict__["lists"] = lists
            __props__.__dict__["milestone_id"] = milestone_id
            __props__.__dict__["name"] = name
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["weight"] = weight
        super(ProjectIssueBoard, __self__).__init__(
            'gitlab:index/projectIssueBoard:ProjectIssueBoard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            assignee_id: Optional[pulumi.Input[int]] = None,
            labels: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            lists: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectIssueBoardListArgs', 'ProjectIssueBoardListArgsDict']]]]] = None,
            milestone_id: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            weight: Optional[pulumi.Input[int]] = None) -> 'ProjectIssueBoard':
        """
        Get an existing ProjectIssueBoard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] assignee_id: The assignee the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] labels: The list of label names which the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectIssueBoardListArgs', 'ProjectIssueBoardListArgsDict']]]] lists: The list of issue board lists
        :param pulumi.Input[int] milestone_id: The milestone the board should be scoped to. Requires a GitLab EE license.
        :param pulumi.Input[str] name: The name of the board.
        :param pulumi.Input[str] project: The ID or full path of the project maintained by the authenticated user.
        :param pulumi.Input[int] weight: The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectIssueBoardState.__new__(_ProjectIssueBoardState)

        __props__.__dict__["assignee_id"] = assignee_id
        __props__.__dict__["labels"] = labels
        __props__.__dict__["lists"] = lists
        __props__.__dict__["milestone_id"] = milestone_id
        __props__.__dict__["name"] = name
        __props__.__dict__["project"] = project
        __props__.__dict__["weight"] = weight
        return ProjectIssueBoard(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="assigneeId")
    def assignee_id(self) -> pulumi.Output[Optional[int]]:
        """
        The assignee the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "assignee_id")

    @property
    @pulumi.getter
    def labels(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        The list of label names which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def lists(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectIssueBoardList']]]:
        """
        The list of issue board lists
        """
        return pulumi.get(self, "lists")

    @property
    @pulumi.getter(name="milestoneId")
    def milestone_id(self) -> pulumi.Output[Optional[int]]:
        """
        The milestone the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "milestone_id")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the board.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or full path of the project maintained by the authenticated user.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter
    def weight(self) -> pulumi.Output[Optional[int]]:
        """
        The weight range from 0 to 9, to which the board should be scoped to. Requires a GitLab EE license.
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectSecurityPolicyAttachmentArgs', 'ProjectSecurityPolicyAttachment']

@pulumi.input_type
class ProjectSecurityPolicyAttachmentArgs:
    def __init__(__self__, *,
                 policy_project: pulumi.Input[str],
                 project: pulumi.Input[str]):
        """
        The set of arguments for constructing a ProjectSecurityPolicyAttachment resource.
        :param pulumi.Input[str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[str] project: The ID or Full Path of the project which will have the security policy project assigned to it.
        """
        pulumi.set(__self__, "policy_project", policy_project)
        pulumi.set(__self__, "project", project)

    @property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> pulumi.Input[str]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @policy_project.setter
    def policy_project(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_project", value)

    @property
    @pulumi.getter
    def project(self) -> pulumi.Input[str]:
        """
        The ID or Full Path of the project which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[str]):
        pulumi.set(self, "project", value)


@pulumi.input_type
class _ProjectSecurityPolicyAttachmentState:
    def __init__(__self__, *,
                 policy_project: Optional[pulumi.Input[str]] = None,
                 policy_project_graphql_id: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 project_graphql_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectSecurityPolicyAttachment resources.
        :param pulumi.Input[str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[str] policy_project_graphql_id: The GraphQL ID of the security policy project.
        :param pulumi.Input[str] project: The ID or Full Path of the project which will have the security policy project assigned to it.
        :param pulumi.Input[str] project_graphql_id: The GraphQL ID of the project to which the security policty project will be attached.
        """
        if policy_project is not None:
            pulumi.set(__self__, "policy_project", policy_project)
        if policy_project_graphql_id is not None:
            pulumi.set(__self__, "policy_project_graphql_id", policy_project_graphql_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if project_graphql_id is not None:
            pulumi.set(__self__, "project_graphql_id", project_graphql_id)

    @property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @policy_project.setter
    def policy_project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_project", value)

    @property
    @pulumi.getter(name="policyProjectGraphqlId")
    def policy_project_graphql_id(self) -> Optional[pulumi.Input[str]]:
        """
        The GraphQL ID of the security policy project.
        """
        return pulumi.get(self, "policy_project_graphql_id")

    @policy_project_graphql_id.setter
    def policy_project_graphql_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_project_graphql_id", value)

    @property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[str]]:
        """
        The ID or Full Path of the project which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project", value)

    @property
    @pulumi.getter(name="projectGraphqlId")
    def project_graphql_id(self) -> Optional[pulumi.Input[str]]:
        """
        The GraphQL ID of the project to which the security policty project will be attached.
        """
        return pulumi.get(self, "project_graphql_id")

    @project_graphql_id.setter
    def project_graphql_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_graphql_id", value)


class ProjectSecurityPolicyAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_project: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This resource can be used to attach a security policy to a pre-existing project
        foo = gitlab.ProjectSecurityPolicyAttachment("foo",
            project="1234",
            policy_project="4567")
        # Or Terraform can create a new project, add a policy to that project,
        # then attach that policy project to other projects.
        my_policy_project = gitlab.Project("my-policy-project", name="security-policy-project")
        policy_yml = gitlab.RepositoryFile("policy-yml",
            project=my_policy_project.id,
            file_path=".gitlab/security-policies/my-policy.yml",
            branch="master",
            encoding="text",
            content=\"\"\"---
        approval_policy:
        - name: test
        description: test
        enabled: true
        rules:
        - type: any_merge_request
            branch_type: protected
            commits: any
        approval_settings:
            block_branch_modification: true
            prevent_pushing_and_force_pushing: true
            prevent_approval_by_author: true
            prevent_approval_by_commit_author: true
            remove_approvals_with_new_commit: true
            require_password_to_approve: false
        fallback_behavior:
            fail: closed
        actions:
        - type: send_bot_message
            enabled: true
        \"\"\")
        # Multiple policies can be attached to a single project by repeating this resource or using a `for_each`
        my_policy = gitlab.ProjectSecurityPolicyAttachment("my-policy",
            project="1234",
            policy_project=my_policy_project.id)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_security_policy_attachment`. For example:

        terraform

        import {

          to = gitlab_project_security_policy_attachment.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project security policy attachments can be imported using an id made up of `project:policy_project_id` where the policy project ID is the project ID of the policy project, e.g.

        ```sh
        $ pulumi import gitlab:index/projectSecurityPolicyAttachment:ProjectSecurityPolicyAttachment foo 1:2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[str] project: The ID or Full Path of the project which will have the security policy project assigned to it.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectSecurityPolicyAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This resource can be used to attach a security policy to a pre-existing project
        foo = gitlab.ProjectSecurityPolicyAttachment("foo",
            project="1234",
            policy_project="4567")
        # Or Terraform can create a new project, add a policy to that project,
        # then attach that policy project to other projects.
        my_policy_project = gitlab.Project("my-policy-project", name="security-policy-project")
        policy_yml = gitlab.RepositoryFile("policy-yml",
            project=my_policy_project.id,
            file_path=".gitlab/security-policies/my-policy.yml",
            branch="master",
            encoding="text",
            content=\"\"\"---
        approval_policy:
        - name: test
        description: test
        enabled: true
        rules:
        - type: any_merge_request
            branch_type: protected
            commits: any
        approval_settings:
            block_branch_modification: true
            prevent_pushing_and_force_pushing: true
            prevent_approval_by_author: true
            prevent_approval_by_commit_author: true
            remove_approvals_with_new_commit: true
            require_password_to_approve: false
        fallback_behavior:
            fail: closed
        actions:
        - type: send_bot_message
            enabled: true
        \"\"\")
        # Multiple policies can be attached to a single project by repeating this resource or using a `for_each`
        my_policy = gitlab.ProjectSecurityPolicyAttachment("my-policy",
            project="1234",
            policy_project=my_policy_project.id)
        ```

        ## Import

        Starting in Terraform v1.5.0 you can use an import block to import `gitlab_project_security_policy_attachment`. For example:

        terraform

        import {

          to = gitlab_project_security_policy_attachment.example

          id = "see CLI command below for ID"

        }

        Import using the CLI is supported using the following syntax:

        GitLab project security policy attachments can be imported using an id made up of `project:policy_project_id` where the policy project ID is the project ID of the policy project, e.g.

        ```sh
        $ pulumi import gitlab:index/projectSecurityPolicyAttachment:ProjectSecurityPolicyAttachment foo 1:2
        ```

        :param str resource_name: The name of the resource.
        :param ProjectSecurityPolicyAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectSecurityPolicyAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 policy_project: Optional[pulumi.Input[str]] = None,
                 project: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectSecurityPolicyAttachmentArgs.__new__(ProjectSecurityPolicyAttachmentArgs)

            if policy_project is None and not opts.urn:
                raise TypeError("Missing required property 'policy_project'")
            __props__.__dict__["policy_project"] = policy_project
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["policy_project_graphql_id"] = None
            __props__.__dict__["project_graphql_id"] = None
        super(ProjectSecurityPolicyAttachment, __self__).__init__(
            'gitlab:index/projectSecurityPolicyAttachment:ProjectSecurityPolicyAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            policy_project: Optional[pulumi.Input[str]] = None,
            policy_project_graphql_id: Optional[pulumi.Input[str]] = None,
            project: Optional[pulumi.Input[str]] = None,
            project_graphql_id: Optional[pulumi.Input[str]] = None) -> 'ProjectSecurityPolicyAttachment':
        """
        Get an existing ProjectSecurityPolicyAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[str] policy_project_graphql_id: The GraphQL ID of the security policy project.
        :param pulumi.Input[str] project: The ID or Full Path of the project which will have the security policy project assigned to it.
        :param pulumi.Input[str] project_graphql_id: The GraphQL ID of the project to which the security policty project will be attached.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectSecurityPolicyAttachmentState.__new__(_ProjectSecurityPolicyAttachmentState)

        __props__.__dict__["policy_project"] = policy_project
        __props__.__dict__["policy_project_graphql_id"] = policy_project_graphql_id
        __props__.__dict__["project"] = project
        __props__.__dict__["project_graphql_id"] = project_graphql_id
        return ProjectSecurityPolicyAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> pulumi.Output[str]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @property
    @pulumi.getter(name="policyProjectGraphqlId")
    def policy_project_graphql_id(self) -> pulumi.Output[str]:
        """
        The GraphQL ID of the security policy project.
        """
        return pulumi.get(self, "policy_project_graphql_id")

    @property
    @pulumi.getter
    def project(self) -> pulumi.Output[str]:
        """
        The ID or Full Path of the project which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "project")

    @property
    @pulumi.getter(name="projectGraphqlId")
    def project_graphql_id(self) -> pulumi.Output[str]:
        """
        The GraphQL ID of the project to which the security policty project will be attached.
        """
        return pulumi.get(self, "project_graphql_id")

